==> ultraman-bocp-gen-codegen-0.0.17-sources.jar: com/xforceplus/ultraman/bocp/gen/util/ApplicationGenerator.java <==
package com.xforceplus.ultraman.bocp.gen.util;

import com.baomidou.mybatisplus.generator.config.DataSourceConfig;
import com.baomidou.mybatisplus.generator.config.GlobalConfig;
import com.baomidou.mybatisplus.generator.config.PackageConfig;
import com.baomidou.mybatisplus.generator.config.StrategyConfig;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.xforceplus.ultraman.bocp.gen.config.ApplicationConfig;
import com.xforceplus.ultraman.bocp.gen.config.ModuleConfig;
import com.xforceplus.ultraman.bocp.gen.config.ProjectConfig;
import com.xforceplus.ultraman.bocp.gen.constant.CodeGenConstant;
import com.xforceplus.ultraman.bocp.gen.generator.BocpAutoGenerator;
import com.xforceplus.ultraman.bocp.gen.po.ModuleInfo;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * mysql 代码生成器演示例子
 * </p>
 *
 * @author wangzheng
 * @since 2019-11-19
 */
public class ApplicationGenerator {

    /**
     * RUN THIS
     */
    public static void main(String[] args) {
//        String modelName = "metadata";

        // 代码生成器
        BocpAutoGenerator mpg = new BocpAutoGenerator();
        // 全局配置
        GlobalConfig gc = new GlobalConfig();
        gc.setAuthor("wangzheng");
        gc.setBaseResultMap(true);
        gc.setOpen(false);
        mpg.setGlobalConfig(gc);

        // 数据源配置
        DataSourceConfig dsc = new DataSourceConfig();
        dsc.setUrl("jdbc:mysql://120.55.249.44:27306/bocp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
        // dsc.setSchemaName("public");
        dsc.setDriverName("com.mysql.jdbc.Driver");
        dsc.setUsername("root");
        dsc.setPassword("xplat");
        mpg.setDataSource(dsc);

//        DataSourceConfig dsc = new DataSourceConfig();
//        dsc.setUrl("jdbc:mysql://localhost:3306/pfcp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
//        // dsc.setSchemaName("public");
//        dsc.setDriverName("com.mysql.jdbc.Driver");
//        dsc.setUsername("root");
//        dsc.setPassword("FGlai123");
//        mpg.setDataSource(dsc);

        // 包配置
        PackageConfig pc = new PackageConfig();
//        pc.setModuleName(modelName);
        pc.setParent("com.xforceplus.ultraman.bocp");
//        pc.setParent("com.xforceplus.ultraman.pfcp");
        mpg.setPackageInfo(pc);

        // 项目配置
        ProjectConfig prjc = new ProjectConfig();
        prjc.setName("ultraman");
        prjc.setCode("ULTRAMAN");
        prjc.setGroupInfo("com.xforceplus");
        prjc.setRemark("ultraman is a platform");
        prjc.setVersion("0.1.5");
        mpg.setProjectConfig(prjc);

        // 应用配置
        ApplicationConfig appc = new ApplicationConfig();
        appc.setName("ultraman-bocp");
        appc.setAlias("Bocp");
        appc.setCode("BOCP");
        appc.setRemark("Bocp is a low code platform");
        appc.setVersion("0.1.5");
        appc.setUrl("https://xxx.gitlab.com/digital");
        ModuleInfo mdi = new ModuleInfo();
        mdi.setName("ultraman-bocp-metadata");
        mdi.setAlias("Metadata");
//        appc.setName("ultraman-pfcp");
//        appc.setAlias("Pfcp");
//        appc.setCode("PFCP");
//        appc.setRemark("PFCP is a low code platform");
//        appc.setVersion("0.1.5");
//        appc.setUrl("https://xxx.gitlab.com/digital");
//        ModuleInfo mdi = new ModuleInfo();
//        mdi.setName("ultraman-pfcp-setting");
//        mdi.setAlias("Setting");
        List<ModuleInfo> mdiList = new ArrayList<>();
        mdiList.add(mdi);
        appc.setModuleList(mdiList);
        mpg.setApplicationConfig(appc);

        //
        mpg.setModuleConfig(new ModuleConfig());

        // 策略配置
        StrategyConfig strategy = new StrategyConfig();
        strategy.setNaming(NamingStrategy.underline_to_camel);
        strategy.setColumnNaming(NamingStrategy.underline_to_camel);
        strategy.setEntityLombokModel(true);
        strategy.setControllerMappingHyphenStyle(true);
        strategy.setTablePrefix(pc.getModuleName() + "_");
        strategy.setSuperMapperClass(CodeGenConstant.SUPER_MAPPER_CLASS);
        mpg.setStrategy(strategy);
        mpg.setEngineType("app");
        mpg.execute();
    }

}

==> ultraman-bocp-gen-codegen-0.0.18-sources.jar: com/xforceplus/ultraman/bocp/gen/util/ApplicationGenerator.java <==
package com.xforceplus.ultraman.bocp.gen.util;

import com.baomidou.mybatisplus.generator.config.DataSourceConfig;
import com.baomidou.mybatisplus.generator.config.GlobalConfig;
import com.baomidou.mybatisplus.generator.config.PackageConfig;
import com.baomidou.mybatisplus.generator.config.StrategyConfig;
import com.baomidou.mybatisplus.generator.config.rules.NamingStrategy;
import com.xforceplus.ultraman.bocp.gen.config.ApplicationConfig;
import com.xforceplus.ultraman.bocp.gen.config.ModuleConfig;
import com.xforceplus.ultraman.bocp.gen.config.ProjectConfig;
import com.xforceplus.ultraman.bocp.gen.constant.CodeGenConstant;
import com.xforceplus.ultraman.bocp.gen.generator.BocpAutoGenerator;
import com.xforceplus.ultraman.bocp.gen.po.ModuleInfo;

import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * mysql 代码生成器演示例子
 * </p>
 *
 * @author wangzheng
 * @since 2019-11-19
 */
public class ApplicationGenerator {

    /**
     * RUN THIS
     */
    public static void main(String[] args) {
        excuteBOCP();
//        excutePFCP();

    }

    public static void excutePFCP(){
        // 代码生成器
        BocpAutoGenerator mpg = new BocpAutoGenerator();
        // 全局配置
        GlobalConfig gc = new GlobalConfig();
        gc.setAuthor("wangzheng");
        gc.setBaseResultMap(true);
        gc.setOpen(false);
        mpg.setGlobalConfig(gc);

        // 数据源配置
        DataSourceConfig dsc = new DataSourceConfig();
        dsc.setUrl("jdbc:mysql://120.55.249.44:27306/pfcp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
        // dsc.setSchemaName("public");
        dsc.setDriverName("com.mysql.jdbc.Driver");
        dsc.setUsername("root");
        dsc.setPassword("xplat");
        mpg.setDataSource(dsc);

        // 包配置
        PackageConfig pc = new PackageConfig();
        pc.setParent("com.xforceplus.ultraman.pfcp");
        mpg.setPackageInfo(pc);

        // 项目配置
        ProjectConfig prjc = new ProjectConfig();
        prjc.setName("ultraman");
        prjc.setCode("ULTRAMAN");
        prjc.setGroupInfo("com.xforceplus");
        prjc.setRemark("ultraman is a platform");
        prjc.setVersion("0.1.5");
        mpg.setProjectConfig(prjc);

        // 应用配置
        ApplicationConfig appc = new ApplicationConfig();
        appc.setName("ultraman-pfcp");
        appc.setAlias("Pfcp");
        appc.setCode("PFCP");
        appc.setRemark("PFCP is a low code platform");
        appc.setVersion("0.1.5");
        appc.setUrl("https://xxx.gitlab.com/digital");
        ModuleInfo mdi = new ModuleInfo();
        mdi.setName("ultraman-pfcp-setting");
        mdi.setAlias("Setting");
        List<ModuleInfo> mdiList = new ArrayList<>();
        mdiList.add(mdi);
        appc.setModuleList(mdiList);
        mpg.setApplicationConfig(appc);

        //
        mpg.setModuleConfig(new ModuleConfig());

        // 策略配置
        StrategyConfig strategy = new StrategyConfig();
        strategy.setNaming(NamingStrategy.underline_to_camel);
        strategy.setColumnNaming(NamingStrategy.underline_to_camel);
        strategy.setEntityLombokModel(true);
        strategy.setControllerMappingHyphenStyle(true);
        strategy.setTablePrefix(pc.getModuleName() + "_");
        strategy.setSuperMapperClass(CodeGenConstant.SUPER_MAPPER_CLASS);
        mpg.setStrategy(strategy);
        mpg.setEngineType("app");
        mpg.execute();
    }

    public static void excuteBOCP(){//        String modelName = "metadata";

        // 代码生成器
        BocpAutoGenerator mpg = new BocpAutoGenerator();
        // 全局配置
        GlobalConfig gc = new GlobalConfig();
        gc.setAuthor("wangzheng");
        gc.setBaseResultMap(true);
        gc.setOpen(false);
        mpg.setGlobalConfig(gc);

        // 数据源配置
        DataSourceConfig dsc = new DataSourceConfig();
        dsc.setUrl("jdbc:mysql://120.55.249.44:27306/bocp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
        // dsc.setSchemaName("public");
        dsc.setDriverName("com.mysql.jdbc.Driver");
        dsc.setUsername("root");
        dsc.setPassword("xplat");
        mpg.setDataSource(dsc);

//        DataSourceConfig dsc = new DataSourceConfig();
//        dsc.setUrl("jdbc:mysql://localhost:3306/pfcp?useUnicode=true&serverTimezone=GMT&useSSL=false&characterEncoding=utf8");
//        // dsc.setSchemaName("public");
//        dsc.setDriverName("com.mysql.jdbc.Driver");
//        dsc.setUsername("root");
//        dsc.setPassword("FGlai123");
//        mpg.setDataSource(dsc);

        // 包配置
        PackageConfig pc = new PackageConfig();
//        pc.setModuleName(modelName);
        pc.setParent("com.xforceplus.ultraman.bocp");
//        pc.setParent("com.xforceplus.ultraman.pfcp");
        mpg.setPackageInfo(pc);

        // 项目配置
        ProjectConfig prjc = new ProjectConfig();
        prjc.setName("ultraman");
        prjc.setCode("ULTRAMAN");
        prjc.setGroupInfo("com.xforceplus");
        prjc.setRemark("ultraman is a platform");
        prjc.setVersion("0.1.14");
        mpg.setProjectConfig(prjc);

        // 应用配置
        ApplicationConfig appc = new ApplicationConfig();
        appc.setName("ultraman-bocp");
        appc.setAlias("Bocp");
        appc.setCode("BOCP");
        appc.setRemark("Bocp is a low code platform");
        appc.setVersion("0.1.14");
        appc.setUrl("https://xxx.gitlab.com/digital");
        ModuleInfo mdi = new ModuleInfo();
        mdi.setName("ultraman-bocp-metadata");
        mdi.setAlias("Metadata");
//        appc.setName("ultraman-pfcp");
//        appc.setAlias("Pfcp");
//        appc.setCode("PFCP");
//        appc.setRemark("PFCP is a low code platform");
//        appc.setVersion("0.1.14");
//        appc.setUrl("https://xxx.gitlab.com/digital");
//        ModuleInfo mdi = new ModuleInfo();
//        mdi.setName("ultraman-pfcp-setting");
//        mdi.setAlias("Setting");
        List<ModuleInfo> mdiList = new ArrayList<>();
        mdiList.add(mdi);
        appc.setModuleList(mdiList);
        mpg.setApplicationConfig(appc);

        //
        mpg.setModuleConfig(new ModuleConfig());

        // 策略配置
        StrategyConfig strategy = new StrategyConfig();
        strategy.setNaming(NamingStrategy.underline_to_camel);
        strategy.setColumnNaming(NamingStrategy.underline_to_camel);
        strategy.setEntityLombokModel(true);
        strategy.setControllerMappingHyphenStyle(true);
        strategy.setTablePrefix(pc.getModuleName() + "_");
        strategy.setSuperMapperClass(CodeGenConstant.SUPER_MAPPER_CLASS);
        mpg.setStrategy(strategy);
        mpg.setEngineType("app");
        mpg.execute();
    }

}
